@@ -1,9 +1,11 @@
 from __future__ import absolute_import
 from __future__ import print_function
-from future import standard_library
-standard_library.install_aliases()
 
 import sys
+if sys.version_info < (3, 0):
+    from future import standard_library
+    standard_library.install_aliases()
+
 import pickle
 import warnings
 import pandas as pd
@@ -11,7 +13,7 @@ import numpy as np
 
 from emspy.query import *
 from .query import Query
-
+from .analyticset import AnalyticSet
 
 class TSeriesQuery(Query):
     """
@@ -168,7 +170,7 @@ class TSeriesQuery(Query):
             df = pd.DataFrame(prm, index=[0])
 
             self.__analytic._param_table = \
-                self.__analytic._param_table.append(df, ignore_index=True, sort=True)
+                pd.concat([self.__analytic._param_table, df], axis=0, join='outer', ignore_index=True, sort=True)
 
             # Put the param into JSON query string
             self.__queryset['select'].append({'analyticId': prm['id']})
@@ -213,7 +215,7 @@ class TSeriesQuery(Query):
                 prm = res_df.iloc[0, :].to_dict()
                 # Add the new parameters to the param table for later uses
                 self.__analytic._param_table = \
-                    self.__analytic._param_table.append(res_df, ignore_index=True, sort=True)
+                    pd.concat([self.__analytic._param_table, res_df], axis=0, join='outer', ignore_index=True, sort=True)
                 save_table = True
 
             # Put the param into JSON query string
@@ -223,6 +225,32 @@ class TSeriesQuery(Query):
         if save_table:
             self.__analytic._save_paramtable()
 
+    def select_from_pset(self, analytic_set_path):
+        """
+        A method for selecting parameters to query from a parameter set
+
+        Parameters
+        ----------
+        analytics_set_name: str
+            set name
+        group_path: list of str
+            the path (folders) to the location of the analytic set
+
+        Returns
+        -------
+        None
+        """
+        # Get the Analytics from the parameter set  using the get_analytic_set() method
+        # from the AnalyticSet Class
+        pset = AnalyticSet(self._conn, self._ems_id)
+        pset_df = pset.get_analytic_set(analytic_set_path)
+        for analytic in pset_df.to_dict(orient='records'):
+            # Adding analytic ids to the query body
+            self.__queryset['select'].append({'analyticId': analytic['id']})
+            # Adding to the columns for iteration over the results
+            self.__columns.append(analytic)
+        
+
     def range(self, start=None, end=None):
         """
         Sets the range for the timeseries
@@ -423,7 +451,7 @@ class TSeriesQuery(Query):
             res_df = self.__analytic.search_param("hours of data (hours)", in_df=True)
             p = res_df.iloc[0].to_dict()
             self.__analytic._param_table = \
-                self.__analytic._param_table.append(res_df, ignore_index=True, sort=True)
+                pd.concat([self.__analytic._param_table, res_df], axis=0, join='outer', ignore_index=True, sort=True)
             self.__analytic._save_paramtable()
         q = {
             "select": [{"analyticId": p["id"]}],
